import { Button } from "@components/Button";
import clsx from "clsx";
import type { PropsWithChildren } from "react";

export interface GridCardProps {
  title: string;
  subtitle?: string;
  buttonCaption?: string;
  buttonTarget?: string;
  img?: string;
  imgAlt?: string;
  light?: boolean;
  icon?: React.ReactNode;
  className?: string;
}

export function GridCard({
  title,
  subtitle,
  children,
  buttonCaption,
  buttonTarget,
  img,
  imgAlt,
  light = false,
  icon,
  className = "",
}: PropsWithChildren<GridCardProps>) {
  return (
    <div
      className={clsx(
        light
          ? "fs-bg-pearl-500 fs-text-grey-900"
          : "fs-bg-grey-900 fs-text-white",
        "fs-flex-1 fs-flex fs-flex-col fs-justify-between",
        className,
      )}
    >
      <div className="fs-flex fs-flex-col">
        {Boolean(img) && (
          <img
            className="fs-object-cover fs-aspect-[16/8]"
            src={img}
            alt={imgAlt}
          />
        )}
        <div
          className={clsx(
            light ? "fs-text-grey-900" : "fs-text-white",
            "fs-prose prose-headings:fs-font-karla fs-p-8",
          )}
        >
          {Boolean(subtitle) && (
            <h4
              className={clsx(
                light ? "fs-text-grey-900" : "fs-text-white",
                "fs-uppercase",
              )}
            >
              {subtitle}
            </h4>
          )}
          <h2
            className={clsx(
              light ? "fs-text-grey-900" : "fs-text-white",
              !subtitle && "fs-mt-8",
            )}
          >
            {title}
          </h2>
          <p className="fs-leading-6">{children}</p>
        </div>
      </div>
      {buttonCaption && (
        <div className="fs-px-8 fs-pb-8 fs-flex fs-justify-end">
          <Button
            className="!fs-px-8 !fs-py-2 md:!fs-py-3 md:!fs-px-8"
            text={buttonCaption}
            href={buttonTarget}
            type={light ? "primary" : "tertiary"}
            icon={icon}
          />
        </div>
      )}
    </div>
  );
}
