import { ArrowLeft, ArrowRight, Close } from "@carbon/icons-react";
import clsx from "clsx";
import type { PropsWithChildren } from "react";

export interface LightboxProps {
  isOpen: boolean;
  onClose: () => void;
  onClickNext: () => void;
  onClickPrev: () => void;
}

export function Lightbox({
  isOpen,
  onClose,
  children,
  onClickNext,
  onClickPrev,
}: PropsWithChildren<LightboxProps>) {
  const buttonClasses =
    "fs-absolute fs-flex fs-items-center fs-justify-center fs-size-10 fs-text-white fs-text-opacity-70 hover:fs-text-opacity-100 fs-transition-all fs-duration-100 fs-ease-in-out";

  return (
    <>
      {isOpen && (
        <div className="fs-fixed fs-inset-0 fs-bg-black/90 fs-z-50 fs-p-8">
          <div className="fs-relative fs-w-full fs-h-full">
            <div className="fs-w-full fs-h-full">{children}</div>

            {onClickPrev && (
              <button
                onClick={onClickPrev}
                className={clsx(
                  buttonClasses,
                  "fs-z-10 fs-left-5 fs-top-1/2 -fs-translate-y-2",
                )}
                title="Previous"
              >
                <ArrowLeft size={32} />
              </button>
            )}
            {onClickNext && (
              <button
                onClick={onClickNext}
                className={clsx(
                  buttonClasses,
                  "fs-z-10 fs-right-5 fs-top-1/2 -fs-translate-y-1/2",
                )}
                title="Next"
              >
                <ArrowRight size={32} />
              </button>
            )}
            {onClose && (
              <button
                onClick={onClose}
                className={clsx(buttonClasses, "fs-z-10 fs-top-5 fs-right-5")}
                title="Close"
              >
                <Close size={32} />
              </button>
            )}
          </div>
        </div>
      )}
    </>
  );
}
