import type { PropsWithChildren } from "react";
import { Link } from "./Link";
import { ChevronRight, UserMultiple } from "@carbon/icons-react";

export interface MessageSpaceProps {
  title?: string;
  target: string;
  name: string;
  description: string;
  image: {
    src: string;
    alt: string;
  };
  memberCount: number;
  tag: string;
  className?: string;
}

export function MessageSpace({
  title,
  target,
  name,
  description,
  image,
  memberCount,
  tag,
  children,
  className = "",
}: PropsWithChildren<MessageSpaceProps>) {
  return (
    <div className={className}>
      {title && (
        <h4 className="fs-font-karla fs-text-3xl fs-leading-9 fs-font-bold fs-text-grey-900 fs-tracking-tighter">
          {title}
        </h4>
      )}
      <div className="fs-rounded-lg fs-bg-grey-200 fs-p-2 fs-mt-5">
        <div>
          <MessageSpaceInfo
            target={target}
            name={name}
            alias={tag}
            description={description}
            image={image}
            memberCount={memberCount}
          />
        </div>
        <div className="fs-flex fs-flex-col fs-gap-2 fs-bg-white">
          {children}
        </div>
      </div>
    </div>
  );
}

interface MessageSpaceInfoProps {
  target: string;
  name: string;
  description: string;
  image: { alt: string; src: string };
  memberCount: number;
  alias: string;
}

export function MessageSpaceInfo({
  target,
  name,
  description,
  image,
  memberCount,
  alias,
}: MessageSpaceInfoProps) {
  return (
    <Link
      className="fs-block fs-px-1 sm:fs-px-0 fs-bg-grey-200 hover:fs-bg-grey-900 fs-border fs-border-transparent focus:fs-border-grey-900 fs-transition-colors fs-ease-in fs-duration-50"
      to={target}
    >
      <div className="fs-group fs-relative fs-flex fs-gap-3 fs-py-4 fs-px-5 sm:fs-px-6">
        <div className="fs-size-12 fs-rounded-full fs-overflow-hidden">
          <img
            className="fs-size-full fs-object-cover"
            alt={image.alt}
            src={image.src}
          />
        </div>
        <div className="fs-w-[calc(100%-3rem)] fs-flex fs-flex-col sm:fs-pr-8 md:fs-pr-6 lg:fs-pr-10">
          <div className="fs-w-full">
            <div className="fs-font-plex fs-flex fs-flex-col fs-justify-between">
              <span className="fs-text-lg fs-leading-5 fs-font-medium fs-text-grey-900 fs-line-clamp-1 group-hover:fs-text-white fs-transition-colors fs-ease-in fs-duration-50">
                {name}
              </span>
              <span className="fs-text-xs fs-leading-4 fs-font-normal fs-text-grey-500 fs-line-clamp-1">
                {alias}
              </span>
              <span className="fs-flex fs-items-center fs-text-xs fs-leading-4 fs-font-normal fs-text-grey-500">
                <UserMultiple className="fs-mr-2" /> {memberCount}
              </span>
            </div>
          </div>
          <div className="fs-hidden sm:fs-block fs-w-full fs-mt-3">
            <p className="fs-font-plex fs-text-sm fs-leading-5 fs-font-normal fs-text-black fs-line-clamp-3 group-hover:fs-text-white fs-transition-colors fs-ease-in fs-duration-50">
              {description}
            </p>
          </div>
        </div>
        <ChevronRight
          size={24}
          className="fs-absolute fs-top-1/2 fs-right-4 lg:fs-right-6 -fs-translate-y-2/4 fs-text-grey-500"
        />
      </div>
    </Link>
  );
}
