import GitlabLogo from "@assets/images/socialMedia/gitlab-color.svg";
import GithubLogo from "@assets/images/socialMedia/github.svg";

export interface RepoCardProps {
  project: string;
  projectTitle: string;
  description: string;
  className?: string;
  target: string;
  platform: "gitlab" | "github";
  stats?: Array<{
    value: string | number;
    icon: React.ReactElement;
  }>;
}

const platformIconMapping = {
  gitlab: GitlabLogo,
  github: GithubLogo,
};

export function RepoCard({
  project,
  projectTitle,
  description,
  className,
  platform,
  stats,
  target,
}: RepoCardProps) {
  return (
    <div className="fs-not-prose">
      <a
        href={target}
        target="_blank"
        rel="noreferrer"
        className={`fs-bg-grey-100 fs-flex fs-gap-2 fs-p-4 md:fs-p-8 ${className || ""}`}
      >
        <div className="fs-flex fs-flex-col md:fs-gap-2 fs-flex-1">
          <h5 className="fs-font-karla fs-font-normal fs-text-base md:fs-text-3xl md:fs-leading-8 fs-text-grey-900 ">
            {project} /{" "}
            <span className="fs-font-bold hover:fs-multi-line-underline fs-multi-line-grey-900">
              {projectTitle}
            </span>
          </h5>
          <p className="fs-font-plex fs-text-sm md:fs-text-lg fs-text-grey-500 fs-line-clamp-3">
            {description}
          </p>
          {stats && (
            <div className="fs-hidden md:fs-flex fs-gap-12 fs-pt-2">
              {stats.map((stat, index) => (
                <div
                  className="fs-text-sm md:fs-text-lg md:fs-leading-7 fs-text-grey-900"
                  key={index}
                >
                  {stat.icon &&
                    (typeof stat.value === "number" || stat.value) && (
                      <div className="fs-flex fs-justify-center fs-items-center fs-gap-2">
                        {stat.icon}
                        {stat.value}
                      </div>
                    )}
                </div>
              ))}
            </div>
          )}
        </div>
        {Boolean(platformIconMapping[platform]) && (
          <div className="fs-py-3 md:fs-py-5 fs-flex fs-justify-end">
            <img
              className="fs-size-8 md:fs-size-11"
              alt={platform}
              src={platformIconMapping[platform]}
            />
          </div>
        )}
      </a>
    </div>
  );
}
