import { Image } from "@components/Image";
import type { Story, StoryDefault } from "@ladle/react";

interface ImageConfigProps {
  caption?: string;
  subCaption?: string;
  tag?: string;
  onFullscreen: () => void;
  showFullscreenButton?: boolean;
}

export const ImageStory: Story<ImageConfigProps> = ({
  caption,
  subCaption,
  tag,
  onFullscreen = () => {
    console.log("Fullscreen clicked");
  },
  showFullscreenButton,
}: ImageConfigProps) => (
  <div style={{ maxWidth: "600px" }}>
    <Image
      key={"abc123"}
      src={"https://picsum.photos/id/102/400/300"}
      subCaption={subCaption}
      caption={caption}
      width={400}
      height={300}
      tag={tag}
      onFullscreen={showFullscreenButton ? onFullscreen : undefined}
    />
  </div>
);

ImageStory.args = {
  caption:
    "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed interdum viverra iaculis. Sed efficitur tortor sit amet justo mollis ullamcorper. Pellentesque scelerisque eu massa vitae ornare. Donec sollicitudin dui ac ipsum dignissim faucibus. Etiam ac pulvinar mi, fringilla iaculis neque. Pellentesque egestas diam sed felis commodo porta.",
  subCaption: "Source: test.com",
  tag: "This is a tag",
  showFullscreenButton: true,
};

export default {
  title: "Atoms",
} satisfies StoryDefault;

ImageStory.storyName = "Image";
ImageStory.meta = {
  descriptionTitle: "Image",
  description:
    "This is a very simple Image component to be used for single images inside of website content. It gives the image a set of sane maximum dimensions. It also adds an optional Tag overlay to the image, creates a figure in the markup and also adds a caption and subcaption.",
};
