import { Feature } from "@components/Feature";
import { Story, StoryDefault } from "@ladle/react";

interface FeatureConfigProps {
  href?: string;
  hrefCaption?: string;
  icon?: "wikis" | "chat" | "scales" | "flash";
  title: string;
  description: string;
}

export const FeatureStory: Story<FeatureConfigProps> = ({
  href,
  hrefCaption,
  title,
  description,
  icon = "wikis",
}: FeatureConfigProps) => (
  <div className="fs-flex fs-flex-col fs-gap-4">
    <Feature
      title={title}
      description={description}
      icon={icon}
      href={href}
      hrefCaption={hrefCaption}
    />
  </div>
);

FeatureStory.args = {
  hrefCaption: "Learn more",
  href: "http://google.de",
  title: "My super special Feature",
  description:
    "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus purus varius a. In hac habitasse platea dictumst. Quisque in lobortis tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum, id cursus orci blandit. Maecenas semper urna sit amet viverra interdum.",
};

FeatureStory.argTypes = {
  icon: {
    options: ["wikis", "chat", "scales", "flash"],
    control: { type: "select" },
    defaultValue: "wikis",
  },
};
export default {
  title: "Molecules",
} satisfies StoryDefault;

FeatureStory.storyName = "Feature";
FeatureStory.meta = {
  descriptionTitle: "Feature",
  description:
    "This is a simple text block, accompanied by a small icon to the side. This is typically used for lists.",
};
