import { SocialMediaIcons } from "@components/SocialMediaIcons";
import { ISocialMediaItem } from "@interfaces/IFooter";
import { Story, StoryDefault } from "@ladle/react";
import clsx from "clsx";

const SOCIAL_MEDIA: ISocialMediaItem[] = [
  { href: "https://www.instagram.com", type: "instagram" },
  { href: "https://www.mastodon.social", type: "mastodon" },
  { href: "https://www.facebook.com", type: "facebook" },
  { href: "https://www.twitter.com", type: "twitter" },
  { href: "https://www.x.com", type: "x" },
  { href: "https://www.gitlab.com", type: "gitlab" },
  { href: "https://www.youtube.com", type: "youtube" },
  { href: "https://www.linkedin.com", type: "linkedin" },
  { href: "https://www.xing.de", type: "xing" },
  { href: "https://www.github.com", type: "github" },
  { href: "https://www.google.de", type: "website" },
  { href: "test@example.com", type: "email" },
  { href: "https://www.bluesky.com", type: "bluesky" },
];

interface SocialMediaIconsStoryProps {
  variant?: "dark" | "light";
}

export const SocialMediaIconsStory: Story<SocialMediaIconsStoryProps> = ({
  variant,
}: SocialMediaIconsStoryProps) => (
  <div className="fs-max-w-2xl">
    <div
      className={clsx(
        variant === "light" ? "fs-bg-grey-900" : "fs-white",
        "fs-p-4",
      )}
    >
      <SocialMediaIcons variant={variant} icons={SOCIAL_MEDIA} />
    </div>
  </div>
);

SocialMediaIconsStory.argTypes = {
  variant: {
    options: ["dark", "light"],
    control: { type: "radio" },
    defaultValue: "dark",
  },
};

export default {
  title: "Molecules",
} satisfies StoryDefault;

SocialMediaIconsStory.storyName = "Social Media Icons";
SocialMediaIconsStory.meta = {
  descriptionTitle: "Social Media Icons",
  description:
    "This renders a horizontal row of given Social Media icons in either dark or light theme. Supported are Instagram, Mastodon, Facebook, Twitter, X, GitLab, YouTube, LinkedIn, Xing, GitHub, Website and E-Mail.",
};
