import { Toolbar } from "@components/Toolbar";
import {
  ChoroplethMap,
  Folders,
  Chat,
  Calendar,
  ApplicationVirtual,
  Email,
  Search,
  UserAvatar,
  Notification,
} from "@carbon/icons-react";
import { IToolbarItem } from "@interfaces/IHeader";
import { Story, StoryDefault } from "@ladle/react";

const iconClasses = "fs-size-6 sm:fs-mr-2 fs-mb-1 sm:fs-mb-0 fs-flex-shrink-0";
const TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Map",
    icon: <ChoroplethMap className={iconClasses} />,
    href: `/de/network/map`,
  },
  {
    title: "Knowledge Hub",
    icon: <Folders className={iconClasses} />,
    href: `/de/hub`,
    onlyDesktop: true,
  },
  {
    title: "Community",
    icon: <Chat className={iconClasses} />,
    href: `/de/network/community`,
  },
  {
    title: "Events",
    icon: <Calendar className={iconClasses} />,
    href: `/de/events`,
  },
  {
    title: "Fab City OS",
    icon: <ApplicationVirtual className={iconClasses} />,
    href: `/de/projects/fcos`,
  },
];

const EXTENDED_TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Search",
    icon: <Search size={24} />,
    href: "/search",
  },
  {
    title: "Email",
    icon: <Email size={24} />,
    href: "/email",
  },
  {
    title: "Notification",
    icon: <Notification size={24} />,
    href: "/notification",
  },
  {
    title: "User",
    icon: <UserAvatar size={24} />,
    href: "/user",
  },
];

export const ToolbarStory: Story = () => (
  <div className="fs-flex fs-flex-col fs-gap-4">
    <div>
      <Toolbar isMobileOpen={false} items={TOOLBAR_ITEMS} />
    </div>
    <div>
      <Toolbar
        isMobileOpen={false}
        items={TOOLBAR_ITEMS}
        extendedToolbarItems={EXTENDED_TOOLBAR_ITEMS}
      />
    </div>
  </div>
);

export default {
  title: "Molecules",
} satisfies StoryDefault;
ToolbarStory.storyName = "Toolbar";
ToolbarStory.meta = {
  descriptionTitle: "Toolbar",
  description:
    "The Toolbar sits below the Topbar and typicall offers some kind of shortcuts/tools to specific website sections. It can also be extended to take up the whole width of the screen. It will then also contain 'extended toolbar items' which are displayed just as icons.",
};
